/* Anjuta
 * Copyright (C) 2002 Jeroen Zwartepoorte
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <libxml/parser.h>
#include <libxml/tree.h>
#include <libgnome/gnome-i18n.h>
#include <libgnome/gnome-macros.h>
#include "anjuta-basic-application-type.h"

struct _AnjutaBasicApplicationTypePrivate {
};

GNOME_CLASS_BOILERPLATE (AnjutaBasicApplicationType, anjuta_basic_application_type, 
			 AnjutaProjectType, ANJUTA_TYPE_PROJECT_TYPE);

static const char *
impl_get_category_name (AnjutaProjectType *type)
{
	return _("Simple");
}

static const char *
impl_get_project_name (AnjutaProjectType *type)
{
	return _("Simple Project");
}

static const char *
impl_get_description (AnjutaProjectType *type)
{
	return _("Generates a simple project with no specific build system.");
}

static const char *
impl_get_backend (AnjutaProjectType *type)
{
	return "gbf-basic:GbfBasicProject";
}

static int
impl_get_druid_page_count (AnjutaProjectType *type,
			   GError **error)
{
	return 0;
}

static GtkWidget *
impl_get_druid_page (AnjutaProjectType *type,
		     int page,
		     GError **error)
{
	return NULL;
}

static void
impl_create_project (AnjutaProjectType *type,
		     AnjutaProjectInfo *info,
		     GError **error)
{
	g_message("not implemented: basic impl_create_project");
}

static void
anjuta_basic_application_type_dispose (GObject *object)
{
	AnjutaBasicApplicationType *type = ANJUTA_BASIC_APPLICATION_TYPE (object);

	g_free (type->priv);
}

AnjutaProjectType *
anjuta_basic_application_type_new (void)
{
	return ANJUTA_PROJECT_TYPE (g_object_new (ANJUTA_TYPE_BASIC_APPLICATION_TYPE, NULL));
}

static void
anjuta_basic_application_type_class_init (AnjutaBasicApplicationTypeClass *klass)
{
	GObjectClass *object_class;
	AnjutaProjectTypeClass *project_class;

	parent_class = g_type_class_peek_parent (klass);
	object_class = G_OBJECT_CLASS (klass);
	project_class = ANJUTA_PROJECT_TYPE_CLASS (klass);

	object_class->dispose = anjuta_basic_application_type_dispose;

	project_class->get_category_name = impl_get_category_name;
	project_class->get_project_name = impl_get_project_name;
	project_class->get_description = impl_get_description;
	project_class->get_backend = impl_get_backend;
	project_class->get_druid_page_count = impl_get_druid_page_count;
	project_class->get_druid_page = impl_get_druid_page;
	project_class->create_project = impl_create_project;
}

static void
anjuta_basic_application_type_instance_init (AnjutaBasicApplicationType *type)
{
	type->priv = g_new0 (AnjutaBasicApplicationTypePrivate, 1);
}
